//! Simple progress bar implementations.
//! use these or create your own!

pub mod simple;
pub use simple::SimpleBar;

pub mod spinny;
pub use spinny::SpinniBuilder;
